/****************************************************************************/
/*


DESCRIPTION

	Defines a table to map the register defined in the TRK register groups (Default, Extended1, Extended2, etc)
	to the groups and group id as provided by Topaz internel implementation

COPYRIGHT

	Copyright 2008-2009 Freescale Semiconductor, Inc.

*/
/****************************************************************************/

#ifndef HYPERREGTABLE_H_
#define HYPERREGTABLE_H_

#include "trk_prefix.h"
#include "dstypes.h"
#include "mpc_P4080_reg.h"

#define kNotDefined -1

HyperRegisterInfo trk_register_table[] =
{
#define DEFAULT_REGISTERS_HYPER_INDEX    0
	// General Purpose Registers
	{ .name="GPR0",  .size=kRegister32, .group=kGroupGPR, .groupId=0       },
	{ .name="SP",    .size=kRegister32, .group=kGroupGPR, .groupId=1       },
	{ .name="GPR2",  .size=kRegister32, .group=kGroupGPR, .groupId=2       },
	{ .name="GPR3",  .size=kRegister32, .group=kGroupGPR, .groupId=3       },
	{ .name="GPR4",  .size=kRegister32, .group=kGroupGPR, .groupId=4       },
	{ .name="GPR5",  .size=kRegister32, .group=kGroupGPR, .groupId=5       },
	{ .name="GPR6",  .size=kRegister32, .group=kGroupGPR, .groupId=6       },
	{ .name="GPR7",  .size=kRegister32, .group=kGroupGPR, .groupId=7       },
	{ .name="GPR8",  .size=kRegister32, .group=kGroupGPR, .groupId=8       },
	{ .name="GPR9",  .size=kRegister32, .group=kGroupGPR, .groupId=9       },
	{ .name="GPR10", .size=kRegister32, .group=kGroupGPR, .groupId=10      },
	{ .name="GPR11", .size=kRegister32, .group=kGroupGPR, .groupId=11      },
	{ .name="GPR12", .size=kRegister32, .group=kGroupGPR, .groupId=12      },
	{ .name="GPR13", .size=kRegister32, .group=kGroupGPR, .groupId=13      },
	{ .name="GPR14", .size=kRegister32, .group=kGroupGPR, .groupId=14      },
	{ .name="GPR15", .size=kRegister32, .group=kGroupGPR, .groupId=15      },
	{ .name="GPR16", .size=kRegister32, .group=kGroupGPR, .groupId=16      },
	{ .name="GPR17", .size=kRegister32, .group=kGroupGPR, .groupId=17      },
	{ .name="GPR18", .size=kRegister32, .group=kGroupGPR, .groupId=18      },
	{ .name="GPR19", .size=kRegister32, .group=kGroupGPR, .groupId=19      },
	{ .name="GPR20", .size=kRegister32, .group=kGroupGPR, .groupId=20      },
	{ .name="GPR21", .size=kRegister32, .group=kGroupGPR, .groupId=21      },
	{ .name="GPR22", .size=kRegister32, .group=kGroupGPR, .groupId=22      },
	{ .name="GPR23", .size=kRegister32, .group=kGroupGPR, .groupId=23      },
	{ .name="GPR24", .size=kRegister32, .group=kGroupGPR, .groupId=24      },
	{ .name="GPR25", .size=kRegister32, .group=kGroupGPR, .groupId=25      },
	{ .name="GPR26", .size=kRegister32, .group=kGroupGPR, .groupId=26      },
	{ .name="GPR27", .size=kRegister32, .group=kGroupGPR, .groupId=27      },
	{ .name="GPR28", .size=kRegister32, .group=kGroupGPR, .groupId=28      },
	{ .name="GPR29", .size=kRegister32, .group=kGroupGPR, .groupId=29      },
	{ .name="GPR30", .size=kRegister32, .group=kGroupGPR, .groupId=30      },
	{ .name="GPR31", .size=kRegister32, .group=kGroupGPR, .groupId=31      },
	{ .name="PC",    .size=kRegister32, .group=kGroupPC,  .groupId=0       },
	{ .name="CR",    .size=kRegister32, .group=kGroupCR,  .groupId=0       },
	{ .name="LR",    .size=kRegister32, .group=kGroupSPR, .groupId=SPR_LR  },
	{ .name="CTR",   .size=kRegister32, .group=kGroupSPR, .groupId=SPR_CTR },
	{ .name="XER",   .size=kRegister32, .group=kGroupSPR, .groupId=SPR_XER },

#define EXTENDED1_REGISTERS_HYPER_INDEX  TRK_DEFAULT_MAX_REGISTER + 1
	// Standard Special Purpose Registers
	{ .name="PVR",   .size=kRegister32, .group=kGroupSPR, .groupId=SPR_PVR     },
	{ .name="MSR",   .size=kRegister32, .group=kGroupMSR, .groupId=0           },
	{ .name="SPRG0", .size=kRegister32, .group=kGroupSPR, .groupId=SPR_SPRG0   },
	{ .name="SPRG1", .size=kRegister32, .group=kGroupSPR, .groupId=SPR_SPRG1   },
	{ .name="SPRG2", .size=kRegister32, .group=kGroupSPR, .groupId=SPR_SPRG2   },
	{ .name="SPRG3", .size=kRegister32, .group=kGroupSPR, .groupId=SPR_SPRG3   },
	{ .name="SRR0",  .size=kRegister32, .group=kGroupSPR, .groupId=SPR_SRR0    },
	{ .name="SRR1",  .size=kRegister32, .group=kGroupSPR, .groupId=SPR_SRR1    },
	{ .name="TBL",   .size=kRegister32, .group=kGroupSPR, .groupId=SPR_TBL     },
	{ .name="TBU",   .size=kRegister32, .group=kGroupSPR, .groupId=SPR_TBU     },
	{ .name="DEC",   .size=kRegister32, .group=kGroupSPR, .groupId=SPR_DEC     },
	// e500mc Special Purpose Registers
	{ .name="PID0",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_PID          },
	{ .name="DECAR",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_DECAR        },
	{ .name="CSRR0",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_CSRR0        },
	{ .name="CSRR1",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_CSRR1        },
	{ .name="DEAR",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_DEAR         },
	{ .name="ESR",          .size=kRegister32, .group=kGroupSPR, .groupId=SPR_ESR          },
	{ .name="IVPR",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVPR         },
	{ .name="USPRG0",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_USPRG0       },
	{ .name="SPRG4",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_SPRG4        },
	{ .name="SPRG5",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_SPRG5        },
	{ .name="SPRG6",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_SPRG6        },
	{ .name="SPRG7",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_SPRG7        },
	{ .name="SPRG8",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_SPRG8        },
	{ .name="SPRG9",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_SPRG9        },
	{ .name="TBLW",         .size=kRegister32, .group=kGroupSPR, .groupId=kNotDefined      },
	{ .name="TBUW",         .size=kRegister32, .group=kGroupSPR, .groupId=kNotDefined      },
	{ .name="PIR",          .size=kRegister32, .group=kGroupSPR, .groupId=SPR_PIR          },
	{ .name="DBSR",         .size=kRegister32, .group=kGroupDebug, .groupId=SPR_DBSR       },
	{ .name="DBCR0",        .size=kRegister32, .group=kGroupDebug, .groupId=SPR_DBCR0      },
	{ .name="DBCR1",        .size=kRegister32, .group=kGroupDebug, .groupId=SPR_DBCR1      },
	{ .name="DBCR2",        .size=kRegister32, .group=kGroupDebug, .groupId=SPR_DBCR2      },
	{ .name="IAC1",         .size=kRegister32, .group=kGroupDebug, .groupId=SPR_IAC1       },
	{ .name="IAC2",         .size=kRegister32, .group=kGroupDebug, .groupId=SPR_IAC2       },
	{ .name="DAC1",         .size=kRegister32, .group=kGroupDebug, .groupId=SPR_DAC1       },
	{ .name="DAC2",         .size=kRegister32, .group=kGroupDebug, .groupId=SPR_DAC2       },
	{ .name="TSR",          .size=kRegister32, .group=kGroupSPR, .groupId=SPR_TSR          },
	{ .name="TCR",          .size=kRegister32, .group=kGroupSPR, .groupId=SPR_TCR          },
	{ .name="IVOR0",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVOR0        },
	{ .name="IVOR1",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVOR1        },
	{ .name="IVOR2",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVOR2        },
	{ .name="IVOR3",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVOR3        },
	{ .name="IVOR4",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVOR4        },
	{ .name="IVOR5",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVOR5        },
	{ .name="IVOR6",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVOR6        },
	{ .name="IVOR7",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVOR7        },
	{ .name="IVOR8",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVOR8        },
	{ .name="IVOR9",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVOR9        },
	{ .name="IVOR10",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVOR10       },
	{ .name="IVOR11",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVOR11       },
	{ .name="IVOR12",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVOR12       },
	{ .name="IVOR13",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVOR13       },
	{ .name="IVOR14",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVOR14       },
	{ .name="IVOR15",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVOR15       },
	{ .name="L1CFG0",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L1CFG0       },
	{ .name="L1CFG1",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L1CFG1       },
	{ .name="NPIDR",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_NPIDR        },
	{ .name="IVOR35",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVOR35       },
	{ .name="MCSRR0",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_MCSRR0       },
	{ .name="MCSRR1",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_MCSRR1       },
	{ .name="MCSR",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_MCSR         },
	{ .name="MCAR",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_MCAR         },
	{ .name="MAS0",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_MAS0         },
	{ .name="MAS1",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_MAS1         },
	{ .name="MAS2",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_MAS2         },
	{ .name="MAS3",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_MAS3         },
	{ .name="MAS4",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_MAS4         },
	{ .name="MAS6",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_MAS6         },
	{ .name="MAS7",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_MAS7         },
	{ .name="TLB0CFG",      .size=kRegister32, .group=kGroupSPR, .groupId=SPR_TLB0CFG      },
	{ .name="TLB1CFG",      .size=kRegister32, .group=kGroupSPR, .groupId=SPR_TLB1CFG      },
	{ .name="HID0",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_HID0         },
	{ .name="L1CSR0",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L1CSR0       },
	{ .name="L1CSR1",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L1CSR1       },
	{ .name="MMUCSR0",      .size=kRegister32, .group=kGroupSPR, .groupId=SPR_MMUCSR0      },
	{ .name="BUCSR",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_BUCSR        },
	{ .name="MMUCFG",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_MMUCFG       },
	{ .name="L2CFG0",       .size=kRegister32, .group=kGroupSPR, .groupId=kNotDefined      },
	{ .name="IVOR36",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVOR36       },
	{ .name="IVOR37",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_IVOR37       },
	{ .name="DSRR0",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_DSRR0        },
	{ .name="DSRR1",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_DSRR1        },
	{ .name="CDCSR0",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_CDCSR0       },
	{ .name="EPR",          .size=kRegister32, .group=kGroupSPR, .groupId=SPR_EPR          },
	{ .name="EPLC",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_EPLC         },
	{ .name="EPSC",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_EPSC         },
	{ .name="L2ERRINJHI",   .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L2ERRINJHI   },
	{ .name="L2ERRINJLO",   .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L2ERRINJLO   },
	{ .name="L2ERRINJCTL",  .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L2ERRINJCTL  },
	{ .name="L2CAPTDATAHI", .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L2CAPTDATAHI },
	{ .name="L2CAPTDATALO", .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L2CAPTDATALO },
	{ .name="L2CAPTECC",    .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L2CAPTECC    },
	{ .name="L2ERRDET",     .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L2ERRDET     },
	{ .name="L2ERRDIS",     .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L2ERRDIS     },
	{ .name="L2ERRINTEN",   .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L2ERRINTEN   },
	{ .name="L2ERRATTR",    .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L2ERRATTR    },
	{ .name="L2ERRADDR",    .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L2ERRADDR    },
	{ .name="L2ERREADDR",   .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L2ERREADDR   },
	{ .name="L2ERRCTL",     .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L2ERRCTL     },
	{ .name="L2CSR0",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L2CSR0       },
	{ .name="ATBL",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_ATBL         },
	{ .name="ATBU",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_ATBU         },
	{ .name="DBCR4",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_DBCR4        },
	{ .name="DDAM",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_DDAM         },
	{ .name="DEVENT",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_DEVENT       },
	{ .name="L1CSR2",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L1CSR2       },
	{ .name="L2CSR1",       .size=kRegister32, .group=kGroupSPR, .groupId=SPR_L2CSR1       },
	{ .name="MCARU",        .size=kRegister32, .group=kGroupSPR, .groupId=SPR_MCARU        },
	{ .name="NSPC",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_NSPC         },
	{ .name="NSPD",         .size=kRegister32, .group=kGroupSPR, .groupId=SPR_NSPD         },
	{ .name="SVR",          .size=kRegister32, .group=kGroupSPR, .groupId=SPR_SVR          },

#define FP_REGISTERS_HYPER_INDEX  EXTENDED1_REGISTERS_HYPER_INDEX + DS_EXTENDED1_MAX_REGISTER + 1
	// Floating Point Registers
	{ .name="FPR0",  .size=kRegister64, .group=kGroupFPR,   .groupId=0  },
	{ .name="FPR1",  .size=kRegister64, .group=kGroupFPR,   .groupId=1  },
	{ .name="FPR2",  .size=kRegister64, .group=kGroupFPR,   .groupId=2  },
	{ .name="FPR3",  .size=kRegister64, .group=kGroupFPR,   .groupId=3  },
	{ .name="FPR4",  .size=kRegister64, .group=kGroupFPR,   .groupId=4  },
	{ .name="FPR5",  .size=kRegister64, .group=kGroupFPR,   .groupId=5  },
	{ .name="FPR6",  .size=kRegister64, .group=kGroupFPR,   .groupId=6  },
	{ .name="FPR7",  .size=kRegister64, .group=kGroupFPR,   .groupId=7  },
	{ .name="FPR8",  .size=kRegister64, .group=kGroupFPR,   .groupId=8  },
	{ .name="FPR9",  .size=kRegister64, .group=kGroupFPR,   .groupId=9  },
	{ .name="FPR10", .size=kRegister64, .group=kGroupFPR,   .groupId=10 },
	{ .name="FPR11", .size=kRegister64, .group=kGroupFPR,   .groupId=11 },
	{ .name="FPR12", .size=kRegister64, .group=kGroupFPR,   .groupId=12 },
	{ .name="FPR13", .size=kRegister64, .group=kGroupFPR,   .groupId=13 },
	{ .name="FPR14", .size=kRegister64, .group=kGroupFPR,   .groupId=14 },
	{ .name="FPR15", .size=kRegister64, .group=kGroupFPR,   .groupId=15 },
	{ .name="FPR16", .size=kRegister64, .group=kGroupFPR,   .groupId=16 },
	{ .name="FPR17", .size=kRegister64, .group=kGroupFPR,   .groupId=17 },
	{ .name="FPR18", .size=kRegister64, .group=kGroupFPR,   .groupId=18 },
	{ .name="FPR19", .size=kRegister64, .group=kGroupFPR,   .groupId=19 },
	{ .name="FPR20", .size=kRegister64, .group=kGroupFPR,   .groupId=20 },
	{ .name="FPR21", .size=kRegister64, .group=kGroupFPR,   .groupId=21 },
	{ .name="FPR22", .size=kRegister64, .group=kGroupFPR,   .groupId=22 },
	{ .name="FPR23", .size=kRegister64, .group=kGroupFPR,   .groupId=23 },
	{ .name="FPR24", .size=kRegister64, .group=kGroupFPR,   .groupId=24 },
	{ .name="FPR25", .size=kRegister64, .group=kGroupFPR,   .groupId=25 },
	{ .name="FPR26", .size=kRegister64, .group=kGroupFPR,   .groupId=26 },
	{ .name="FPR27", .size=kRegister64, .group=kGroupFPR,   .groupId=27 },
	{ .name="FPR28", .size=kRegister64, .group=kGroupFPR,   .groupId=28 },
	{ .name="FPR29", .size=kRegister64, .group=kGroupFPR,   .groupId=29 },
	{ .name="FPR30", .size=kRegister64, .group=kGroupFPR,   .groupId=30 },
	{ .name="FPR31", .size=kRegister64, .group=kGroupFPR,   .groupId=31 },
	{ .name="FPSCR", .size=kRegister32, .group=kGroupFPSCR, .groupId=0  },

#define EXTENDED2_REGISTERS_HYPER_INDEX  FP_REGISTERS_HYPER_INDEX + TRK_FLOAT_MAX_REGISTER + 1
	// Local access control - Local configuration control
	{ .name="CCSRBARH", .size=kRegister32, .group=kGroupMMR, .groupId=0 },
	{ .name="CCSRBARL", .size=kRegister32, .group=kGroupMMR, .groupId=1 },
	// e500mc Performance Monitor Registers
	{ .name="UPMC0",    .size=kRegister32, .group=kGroupPMR, .groupId=PMR_UPMC0   },
	{ .name="UPMC1",    .size=kRegister32, .group=kGroupPMR, .groupId=PMR_UPMC1   },
	{ .name="UPMC2",    .size=kRegister32, .group=kGroupPMR, .groupId=PMR_UPMC2   },
	{ .name="UPMC3",    .size=kRegister32, .group=kGroupPMR, .groupId=PMR_UPMC3   },
	{ .name="PMC0",     .size=kRegister32, .group=kGroupPMR, .groupId=PMR_PMC0    },
	{ .name="PMC1",     .size=kRegister32, .group=kGroupPMR, .groupId=PMR_PMC1    },
	{ .name="PMC2",     .size=kRegister32, .group=kGroupPMR, .groupId=PMR_PMC2    },
	{ .name="PMC3",     .size=kRegister32, .group=kGroupPMR, .groupId=PMR_PMC3    },
	{ .name="UPMLCA0",  .size=kRegister32, .group=kGroupPMR, .groupId=PMR_UPMLCA0 },
	{ .name="UPMLCA1",  .size=kRegister32, .group=kGroupPMR, .groupId=PMR_UPMLCA1 },
	{ .name="UPMLCA2",  .size=kRegister32, .group=kGroupPMR, .groupId=PMR_UPMLCA2 },
	{ .name="UPMLCA3",  .size=kRegister32, .group=kGroupPMR, .groupId=PMR_UPMLCA3 },
	{ .name="PMLCA0",   .size=kRegister32, .group=kGroupPMR, .groupId=PMR_PMLCA0  },
	{ .name="PMLCA1",   .size=kRegister32, .group=kGroupPMR, .groupId=PMR_PMLCA1  },
	{ .name="PMLCA2",   .size=kRegister32, .group=kGroupPMR, .groupId=PMR_PMLCA2  },
	{ .name="PMLCA3",   .size=kRegister32, .group=kGroupPMR, .groupId=PMR_PMLCA3  },
	{ .name="UPMLCB0",  .size=kRegister32, .group=kGroupPMR, .groupId=PMR_UPMLCB0 },
	{ .name="UPMLCB1",  .size=kRegister32, .group=kGroupPMR, .groupId=PMR_UPMLCB1 },
	{ .name="UPMLCB2",  .size=kRegister32, .group=kGroupPMR, .groupId=PMR_UPMLCB2 },
	{ .name="UPMLCB3",  .size=kRegister32, .group=kGroupPMR, .groupId=PMR_UPMLCB3 },
	{ .name="PMLCB0",   .size=kRegister32, .group=kGroupPMR, .groupId=PMR_PMLCB0  },
	{ .name="PMLCB1",   .size=kRegister32, .group=kGroupPMR, .groupId=PMR_PMLCB1  },
	{ .name="PMLCB2",   .size=kRegister32, .group=kGroupPMR, .groupId=PMR_PMLCB2  },
	{ .name="PMLCB3",   .size=kRegister32, .group=kGroupPMR, .groupId=PMR_PMLCB3  },
	{ .name="UPMGC0",   .size=kRegister32, .group=kGroupPMR, .groupId=PMR_UPMGC0  },
	{ .name="PMGC0",    .size=kRegister32, .group=kGroupPMR, .groupId=PMR_PMGC0   }
};

const ui32 kTrkRegisterTableNum = sizeof(trk_register_table) / sizeof(HyperRegisterInfo);

#endif /* HYPERREGTABLE_H_ */
