/****************************************************************************/
/*

DESCRIPTION

	Implements the required macros in order to move the global variables defined
	in the agent to a per virtual core private way.

COPYRIGHT

	Copyright 2008-2010 Freescale Semiconductor, Inc.

*/
/****************************************************************************/

#ifndef __PRIVATEDATA_H
#define __PRIVATEDATA_H

#include "trk_prefix.h"
#include "dstypes.h"
#include "target.h"

#ifdef IS_SMP

#include <libos/malloc.h>
#include <libos/trapframe.h>
#include <byte_chan.h>

#include "smp.h"

#ifndef CHANNEL_RCV_BUFFER
#define CHANNEL_RCV_BUFFER 256 /* the receive buffer size should be as large as possible */
#endif

#ifndef CHANNEL_SND_BUFFER
#define CHANNEL_SND_BUFFER 128 /* the send buffer size should be tuned for the specific send device */
#endif

typedef struct
{
	ui16 m_currentPos;                    /* current position in the received buffer */
	short m_noReceived;                   /* the current number of received bytes */
	ui8* m_sndBufferStart;                /* the current position in the buffer */
	ui8* m_sndBufferEnd;                  /* the current position in the buffer */
	byte_chan_handle_t* m_byteChanHandle; /* communication byte channel for the current VCPU */
	ui8  m_recBuffer[CHANNEL_RCV_BUFFER]; /* the current receive buffer */
	ui8  m_sndBuffer[CHANNEL_SND_BUFFER]; /* the current send buffer */
} ByteChannelHandler;

/* Structure to store all private global data */
typedef struct
{
	/* Portable global data for a private implementation
	 * The trk hypervisor agent private data has to start with the Portable
	 * private data type defined in smp.h
	 */
	TrkPrivateContext portableData;

	/* private Hypervisor TRK target implementation data */
	trapframe_t* m_guestFrame;            /* defines the current guest frame */
	int m_geventId;                       /* the gevent identifier on this vcpu */
	void* m_logBuffer;                    /* buffer necessary by the log on the VCPU */
	int m_in_reset;                       /* if are reseting the vcpu */
	ByteChannelHandler m_channelHandler;  /* communication byte channel handler for the current VCPU */

	/* Guest and Agent State specific to PA implementation */
	void* m_gTRKState;   /* current trk state */
	void* m_gCPUState;   /* current guest state */
	void* m_gStepStatus; /* current step status if any */

	/* private data used on step operations */
	uint32_t m_msr_instr; /* saved instruction that affects msr during its execution (needed on pre and post step operations) */
	uint32_t m_step_pc_addr; /* saved PC from where a step operation was initiated (needed on pre and post step operations) */
	uint32_t m_step_modif_msr_bits; /* bits modified in MSR on a step (needed on pre and post step operations) */

	/* private data used when reading TLB entries */
	tlb_entry_t* m_gTlbEntry; /* last TLB entry read from HV */
} TopazTrkVcpuContext;

/* utility macros to reference the fields in the private data structure */
#define GUEST_FRAME m_guestFrame
#define BYTE_CHANNEL_HANDLER m_channelHandler
#define BYTE_CHANNEL m_channelHandler.m_byteChanHandle
#define GEVENT_ID m_geventId
#define LOG_BUFFER m_logBuffer
#define IN_RESET m_in_reset

#define TRK_STATE m_gTRKState
#define GUEST_STATE m_gCPUState
#define STEP_STATUS m_gStepStatus

#define MSR_INSTR m_msr_instr
#define STEP_PC_ADDR m_step_pc_addr
#define STEP_MODIF_MSR_BITS m_step_modif_msr_bits

#define TLB_ENTRY m_gTlbEntry

/* macro that will be used by trk agent to reference a private global data */
#define PRIVATE_DATA_HYPER(struct_member) \
	((TopazTrkVcpuContext*)(get_gcpu()->dbgstub_cpu_data))->struct_member

/* macro that will be used by trk agent to reference a private global data of any cpu */
#define PRIVATE_DATA_HYPER_CPU(struct_member, cpu) \
	((TopazTrkVcpuContext*)(cpu->dbgstub_cpu_data))->struct_member

#endif /* IS_SMP */

#endif
