/****************************************************************************/
/*

DESCRIPTION

	Default transport configuration file.  The default configuration is
	a single communication channel via serial port using the default
	CodeWarriorTRK message framing (rfc1662).

	To create a custom configuration for a specific board, copy this
	file to the board directory and modify the new copy.

COPYRIGHT

	Copyright 2008-2009 Freescale Semiconductor, Inc.

*/
/****************************************************************************/
#include "trk_prefix.h"
#include "target.h"
#include "PrivateData.h"
#include "transport.h"
#include "rfc1662.h"
#include "byte_chan_wrapper.h"

#define TRK_TRANSPORT_NUM_COMM_PORTS			1

extern CharLayerApi gByteChanApi;

/*
 * Now for the SMP case we will be using a Transport Table for each virtual core
 * we are debugging. They will each hold the existing communication layers for each
 * available chanel for each core.
 */
void InitializeTransportTable( void )
{
	Transport* transportTable = NULL;
	MsgLayer* transportRfc1662Layer = NULL;
	Rfc1662Params* transportRfc1662Params = NULL;
	CharLayer* transportByteChanLayer = NULL;

	transportTable         = (Transport*)malloc(sizeof(Transport));
	transportRfc1662Layer  = (MsgLayer*)malloc(sizeof(MsgLayer));
	transportRfc1662Params = (Rfc1662Params*)malloc(sizeof(Rfc1662Params));
	transportByteChanLayer = (CharLayer*)malloc(sizeof(CharLayer));

	transportTable->active  = true;
	transportTable->used    = false;
	transportTable->port    = kByteChan;
	transportTable->channel = kChannel_0;
	transportTable->layer   = transportRfc1662Layer;

	/****************************************************************************/
	/* Define framing layer & parameters (used to frame serial messages).
	 * CodeWarriorTRK interfaces directly with this layer.  This layer uses
	 * the Byte Channel layer for the actual communication.
	 * Define framing layer & parameters.
	 */
	/****************************************************************************/
	transportRfc1662Params->nextLayer = transportByteChanLayer;
	transportRfc1662Layer->params     = transportRfc1662Params;
	transportRfc1662Layer->api        = &gRfc1662Api;


	/****************************************************************************/
	/* Define Byte Channel layer & parameters.  Each core will have it's own
	 * private byte channel handler that will be passed as a reference
	 * to the layer's API to be used for communication. We will create an
	 * instance of this transport layer based on the shared API and the
	 * private location of the byte channel handle for each virtual core.
	 * The location will be later filled with the actual pointer to a valid
	 * byte channel handle
	 */
	/****************************************************************************/
	transportByteChanLayer->params = &PRIVATE_DATA_HYPER(BYTE_CHANNEL_HANDLER);
	transportByteChanLayer->api    = &gByteChanApi;

	PRIVATE_DATA(TRANSPORT_TABLE_ENTRY) = transportTable;

	/****************************************************************************/
	/* Define the number of available communication ports                       */
	/****************************************************************************/
	PRIVATE_DATA(TRANSPORT_NUM_PORTS) = TRK_TRANSPORT_NUM_COMM_PORTS;

	/****************************************************************************/
	/* Define the number of communication ports which can remain active at one time*/
	/****************************************************************************/
	PRIVATE_DATA(TRANSPORT_NUM_PORTS_ACTIVE) = 1;

	/****************************************************************************/
	/* gTransportPrimaryIndex is the index of the primary port.
	 * Primary port is the fastest available port which CodeWarriorTRK will
	 * use to send big messages (length > TRK_TRANSPORT_MSG_THRESHOLD (0x1000)).
	 *
	 * For example, if CodeWarriorTRK supports two types of communications ports:
	 * serial (index = 0) and ethernet (index == 1), then
	 * gTransportPrimaryIndex should be defined as 1.
	 */
	/****************************************************************************/
	PRIVATE_DATA(TRANSPORT_PRIMARY_INDEX) = 0;
}
