/****************************************************************************/
/*

DESCRIPTION

	Defines specific to a target running under the P4080 Topaz hypervisor.

COPYRIGHT

	Copyright 2008-2009 Freescale Semiconductor, Inc.
*/
/****************************************************************************/

#pragma once

#include "dstypes.h"
#include "ppc_version.h"

/****************************************************************************/


#define DS_TARGET_NAME				"P4080"

#define TRK_BAUD_RATE				kBaud115200

#define DS_PROTOCOL					DS_PROTOCOL_HYPER

#define DS_CPU_MAJOR_TYPE			DS_CPU_MAJOR_PPC
#define DS_CPU_MINOR_TYPE			TargetCPUMinorType()

/*
 ** we set the hyper trk anget to be interrupt driven
 */
#define TRK_TRANSPORT_INT_DRIVEN    (1)
#define TRK_MSG_SEQUENCE_IDS		(0)

/*
** The following string is displayed on the LCD panel or other
** on-board display device.  For boards which do not have this
** ability, don't define BOARD_WELCOME_STRING.
*/

/* #define BOARD_WELCOME_STRING */

/*
** For an interrupt-driven transport, define the interrupt mask and
** interrupt key so that the TRK can identify the interrupt which
** corresponds the communication transport.  Using the interrupt
** ID or cause register, it is the interrupt for which:
** id == TRK_TRANSPORT_INT_KEY
**
** For PPC, check if the exception id == 0x0500 (External interrupt).
**
** For Maximer MPC7400 board, the UART interrupt uses
**	external interrupt line.
*/
#define TRK_TRANSPORT_INT_KEY		0x00000500

/*
 * Support Mask - Used to tell the host which commands are supported by
 * this implementation of CodeWarriorTRK.  If using the default, simply include
 * "default_smask.h".  Otherwise, make a local copy of the contents of
 * that file and modify them here.
 */

#include "default_smask.h"

/*
** This board runs at 3.00 Ghz.  A 30-second timeout
** would require 30 * x million cycles.  Assume y cycles
** executed per timeout check.
**
** The TIMEOUT_COUNT is the number of checks per timeout:
**
**	TIMEOUT_COUNT = checks/timeout
**				  = (sec/timeout) * ((cycles/sec) / (cycles/check))
*/

#define CPU_SPEED				(3 * (ui64)1000000000)
#define TIMEOUT_SECS			30
#define CHECK_CYCLES			500

#define TIMEOUT_COUNT			(TIMEOUT_SECS * (CPU_SPEED / CHECK_CYCLES))


#include "timeout.h"


/*
** A few defines are needed by assembly code, but the assembler
** cannot handle some of the C-specific things included in this
** file.  Any defines needed by assembly code are put in the
** following assembler-friendly header file.  Those defines
** are also useful for C code, so include them here.
*/
//#include "target_asm.h"

/*
** Target-specific includes that define things needed by
** portable code.
*/


/*
** Defines if the target already includes board specifig register definitions
*/
#define HAS_REGISTER_DEFINITION (1)

/*
** Defines that this agent will run on a multicore/multithreading system
** This will require that certain static global variables in the trk agent
** expecially communication states be hold in a core context specific way
*/
#define IS_SMP (1)

/*
** Defines that this agent will run using small stacks
** This will be used not to alloc large data on the call stacks
*/
#define USE_SMALL_STACK (1)

/* define the PRIVATE_CONTEXT macro to point to the private start address of the
** memory layout that holds our private trk agent data. Now it uses the topaz's
** gcpu_t's, debug_stub_data member to store the private data in a per core private way
*/
#ifndef CONFIG_DEBUG_STUB
#define CONFIG_DEBUG_STUB (1)
#endif
#include <percpu.h>
#include <malloc.h>
#define PRIVATE_CONTEXT get_gcpu()->dbgstub_cpu_data

/*
** Provides the entry offset for DBCR0 register in hypervisor table register mappings
*/
#define DBCR0_TABLE_INDEX 1

#include "mpc_P4080_reg.h"
