/****************************************************************************/
/*

DESCRIPTION

	Hypervisor-specific implementation of the guest access API.
	Provides basic access to guest resources, like registers and memory.

COPYRIGHT

	Copyright 2008-2010 Freescale Semiconductor, Inc.

*/
/****************************************************************************/


#ifndef HYPERVISOR_GUEST_ACCESS_H_
#define HYPERVISOR_GUEST_ACCESS_H_

#include "trk_prefix.h"
#include "dstypes.h"
#include "targimpl.h"
#include "targimpl_ppc.h"

#include <libos/trapframe.h>
#include <greg.h>

#include <libos/fsl-booke-tlb.h>

typedef enum {
	kPhysicalGuest,
	kVirtualDataGuest32,/*current guest AS & PID is assumed for the virtual address*/
	kVirtualInstrGuest32,/*current guest AS & PID is assumed for the virtual address*/
	kPhysicalHypervsor32,
}MemorySpace;

typedef ui8 byte;

typedef enum {
	kRegister32, /* 32 bit registers */
	kRegister64  /* 64 bit registers */
} RegisterSize;

typedef enum
{
	kGroupUnknown = 0x0,
	kGroupGPR     = 0x1,
	kGroupFPR     = 0x2,
	kGroupPC      = 0x3,
	kGroupMSR     = 0x4,
	kGroupCR      = 0x5,
	kGroupSPR     = 0x6,
	kGroupPMR     = 0x7,
	kGroupFPSCR   = 0x8,
	kGroupMMR     = 0x9,
	kGroupDebug   = 0x10
} RegisterGroup;

typedef struct {
	const char* name;
	RegisterSize size;
	RegisterGroup group;
	int groupId;
} HyperRegisterInfo;

trapframe_t* GetGuestTrapFrame(void);

bool ConvertTrkRegisterId(DSMessageRegisterOptions regSet, ui32 trkSetId, HyperRegisterInfo** toHyperRegInfo);

bool read_register(trapframe_t *trap_frame, HyperRegisterInfo* regInfo, byte* reg_value);

bool write_register(trapframe_t *trap_frame, HyperRegisterInfo* regInfo, byte* reg_value);

bool read_tlb(tlb_entry_t *tlb, unsigned int *flag);

ui32 GetCCSRBAR(RegisterSize size, byte* buf);

ui32 read_memory(MemorySpace space, ui64 startAddress, ui32 size, byte* buf);

ui32 write_memory(MemorySpace space, ui64 startAddress, ui32 size, byte* buf);


typedef void (*debug_event_handler)(trapframe_t*);

ui32 register_debug_handler(debug_event_handler handler);

void PreStepOperations(void);
void PostStepOperations(void);

#endif /*HYPERVISOR_GUEST_ACCESS_H_*/
