/****************************************************************************/
/*


DESCRIPTION

	API for target-specific implementation.

	Register numbers for P4080

	These register blocks are accessed via the kDSReadRegisters and
	kDSWriteRegisters messages.  The register number for a specific
	register is determined by its corresponding element number in these
	structures.  The register data in the messages must conform to
	the structures defined here in big-endian format.

COPYRIGHT

	Copyright 2008-2010 Freescale Semiconductor, Inc.

*/
/****************************************************************************/

#pragma once

#include "dstypes.h"
#include "ppc_reg.h"	// Generic PowerPC Register Definitions

/****************************************************************************/
/****************************************************************************/



// e500mc - specific registers here


/****************************************************************************/
/*
 * Default register block
 */
#undef TRK_DEFAULT_MIN_REGISTER
#undef TRK_DEFAULT_MAX_REGISTER
#define TRK_DEFAULT_MIN_REGISTER	0
#define TRK_DEFAULT_MAX_REGISTER	36

/*
 * Floating Point register block
 */
#undef TRK_FLOAT_MIN_REGISTER
#undef TRK_FLOAT_MAX_REGISTER
#define TRK_FLOAT_MIN_REGISTER			0
#define TRK_FLOAT_MAX_REGISTER			32

/*
 * Extended1 registers block
 */
#define DS_EXTENDED1_MIN_REGISTER_P4080	0
#define DS_EXTENDED1_MAX_REGISTER_P4080	110

#define DS_EXTENDED1_MIN_REGISTER       DS_EXTENDED1_MIN_REGISTER_P4080
#define DS_EXTENDED1_MAX_REGISTER       DS_EXTENDED1_MAX_REGISTER_P4080

/*
 * Extended2 registers block
 */
#define DS_EXTENDED2_MIN_REGISTER_P4080	0
#define DS_EXTENDED2_MAX_REGISTER_P4080	28

#define DS_EXTENDED2_MIN_REGISTER       DS_EXTENDED2_MIN_REGISTER_P4080
#define DS_EXTENDED2_MAX_REGISTER       DS_EXTENDED2_MAX_REGISTER_P4080

/*
 * TLB0 registers block
 */
#define DS_TLB0_MIN_REGISTER_P4080	0
#define DS_TLB0_MAX_REGISTER_P4080	511

#define DS_TLB0_MIN_REGISTER       DS_TLB0_MIN_REGISTER_P4080
#define DS_TLB0_MAX_REGISTER       DS_TLB0_MAX_REGISTER_P4080

/*
 * TLB1 registers block
 */
#define DS_TLB1_MIN_REGISTER_P4080	0
#define DS_TLB1_MAX_REGISTER_P4080	15

#define DS_TLB1_MIN_REGISTER       DS_TLB1_MIN_REGISTER_P4080
#define DS_TLB1_MAX_REGISTER       DS_TLB1_MAX_REGISTER_P4080

/*
 * The number of MAS entries from a tlb entry structure exposed by HV
 */
#define MAS_NR 6

//	full processor state
typedef struct ProcessorState_PPC_P4080
{
	DefaultType	PC; /* Program counter */
	Extended1Type exceptionID; /* upper 16 bits same as vector #, e.g. 0x0200 (read-only) */
#if TRK_TRANSPORT_INT_DRIVEN
	DefaultType 			transport_handler_saved_ra;
#endif
} ProcessorState_PPC_P4080;

typedef ProcessorState_PPC_P4080	ProcessorState_PPC;
