/****************************************************************************/
/*

DESCRIPTION

    	Target-specific implementation of continue for a PowerPC guest running 
	under a hypervisor

COPYRIGHT

	Copyright 2008-2010 Freescale Semiconductor, Inc.

*/
/****************************************************************************/

/* TRK includes */
#include "trk_prefix.h"
#include "usr_put.h"		// must be included before msgcmd.h
#include "targimpl.h"
#include "targimpl_ppc.h"

#include "hypervisor_guest_access.h"

#include "transport.h"

#include "PrivateData.h"

/****************************************************************************/
/*
 *	HyperTargetContinue
 */
/****************************************************************************/
DSError HyperTargetContinue()
{
	// Whatever the target process stopped state was, it will now be false
	TargetSetStopped( false );

	// FIXME: for now we just put a shutdown in the queue
	// we should use the suspend/run core API once it will be available
	NubEvent event;
	ConstructEvent( &event, kShutdownEvent );
	/*
	** Post the event to be handled in the main loop. This will
	** cause the mainloop to exit, before processing other events,
	** since the event queue should be empty as this function is called
	** in Idle(), after the target stopped flag was set to false
	*/
	PostEvent(&event);


	return kNoError;
}

/****************************************************************************/
/*
 *	__reset
 */
/****************************************************************************/
void __reset( void )
{
	gcpu_t* gcpu = get_gcpu();

	// When we reset we set the target as logically stopped in order to be
	// able to wait for a connect message when the vcpu_start hook gets called


	__puts("Reseting Target\r\n");

	if (!gcpu->guest || restart_guest(gcpu->guest, "restart", "trk"))
	{
		/* we could not restart */
		return;
	}

	PRIVATE_DATA_HYPER(IN_RESET) = true;

	if (PRIVATE_DATA(TRK_AUTO_DOWNLOAD))
	    gcpu->guest->no_auto_load = 0;
	else
	    gcpu->guest->no_auto_load = 1; // we ask the hv not to load the default partition elf if auto download is disabled

	// Cotinue this core for returning from the even_handler loop TRK space to the HV space
    HyperTargetContinue();
}


