/****************************************************************************/
/*

DESCRIPTION

	PPC instruction constants & macros.
	
COPYRIGHT

	Copyright 1999-2004, 2006, 2008-2010 Freescale Semiconductor, Inc.

*/
/****************************************************************************/

#ifndef __eppcreg_h__
#define __eppcreg_h__


/*
 *	Default register block (all registers typically requested by debugger)
 */


typedef ui32	DefaultType;
typedef ui32	Extended1Type;
typedef ui64	FloatType;
typedef ui128   Extended2Type;
typedef FloatType FPType;	/* TRK core calls it FPType */


typedef struct Default_PPC
{
	DefaultType	GPR[32];
	DefaultType	PC;
	DefaultType	LR;
	DefaultType	CR;
	DefaultType	CTR;
	DefaultType	XER;
} Default_PPC;

/*
** Register indices
*/
#define TRK_DEFAULT_GPR( x )		(x)
#define TRK_DEFAULT_PC				32
#define TRK_DEFAULT_LR				33
#define TRK_DEFAULT_CR				34
#define TRK_DEFAULT_CTR				35
#define TRK_DEFAULT_XER				36

#define TRK_DEFAULT_MIN_REGISTER	0
#define TRK_DEFAULT_MAX_REGISTER	(sizeof( Default_PPC ) / sizeof( DefaultType ) - 1)

#define TRK_DEFAULT_SIZE			(sizeof( DefaultType ))


typedef struct Float_PPC
{
	FloatType FPR[32];
	FloatType FPSCR;
	FloatType FPECR;				/* only supported on some processors */
} Float_PPC;

/*
** Register indices
*/
#define TRK_FLOAT_FPR( x )			(x)
#define TRK_FLOAT_FPSCR				32
#define TRK_FLOAT_FPECR				33

#define TRK_FLOAT_MIN_REGISTER			0
#define TRK_FLOAT_MAX_REGISTER			(sizeof( Float_PPC ) / sizeof( FloatType ) - 1)

#define TRK_FLOAT_SIZE					(sizeof( FloatType ))


/*
 * Info stored in NotifyStopped message.
 */

typedef DefaultType		PCType;
typedef	ui32			InstructionType;
typedef ui16			ExceptionCauseType;

typedef struct StopInfo_PPC
{
	PCType	PC;
	InstructionType	PCInstruction;		/* instruction at PC */
	ExceptionCauseType	exceptionID;	/* same as vector #, e.g. 0x0200 */
} StopInfo_PPC;


/*
 * PPC Exception type 16 bit mask
 * TRAP ICMP IAC1 IAC2 IAC3 IAC4 DAC1R DAC1W DAC2 DAC2W
 */
typedef enum {
	PPC_TRAP_DEBUG_EXCEPTION = 0x0001,
	PPC_ICMP_DEBUG_EXCEPTION = 0x0002,
	PPC_IAC1_DEBUG_EXCEPTION = 0x0004,
	PPC_IAC2_DEBUG_EXCEPTION = 0x0008,
	PPC_IAC3_DEBUG_EXCEPTION = 0x0010,
	PPC_IAC4_DEBUG_EXCEPTION = 0x0020,
	PPC_DAC1R_DEBUG_EXCEPTION = 0x0040,
	PPC_DAC1W_DEBUG_EXCEPTION = 0x0080,
	PPC_DAC2R_DEBUG_EXCEPTION = 0x0100,
	PPC_DAC2W_DEBUG_EXCEPTION = 0x0200
} PPC_ExceptionTypes;

/*
 * Info stored in NotifyException message.
 */

typedef StopInfo_PPC ExceptionInfo_PPC;

/*
** Info used by breakpoint code to restore (unset)
** breakpoints.  For software breakpoints it is just
** the saved instruction.
*/

typedef InstructionType BreakpointRestore;


#define TRK_EXTENDED2_SIZE			(sizeof(Extended2Type))


#define _555_VERSION      0x00020020
#define _7XX_VERSION      0x0008
#define _7400_VERSION     0x000c
#define _7410_VERSION     0x800c
#define _7455_VERSION     0x8001		// bits 0..15 of PVR on 7455  // Kobler
#define _8260_VERSION     0x0081
#define _PQ38_VERSION     0x8021
#define _QorIQ_P4_VERSION 0x8023

// If target specific code does not already defines register ids
#if !defined(HAS_REGISTER_DEFINITION)

//	Special purpose register numbers

#define SPR_XER			1
#define SPR_LR			8
#define SPR_CTR			9
#define SPR_DSISR		18
#define SPR_DAR			19
#define SPR_DEC			22
#define SPR_SRR0		26
#define SPR_SRR1		27
#define SPR_CSRR0		58
#define SPR_CSRR1		59

#define SPR_PVR			287
#define SPR_SPRG0		272
#define SPR_SPRG1		273
#define SPR_SPRG2		274
#define SPR_SPRG3		275
#define TBR_TBL_READ	268
#define TBR_TBU_READ	269
#define TBR_TBL_WRITE	284
#define TBR_TBU_WRITE	285
#define	SPR_FPECR		1022

#define _555_VERSION	0x00020020
#define _7XX_VERSION 	0x0008
#define _7400_VERSION   0x000c
#define _7410_VERSION   0x800c
#define _7455_VERSION   0x8001		// bits 0..15 of PVR on 7455
#define _8260_VERSION 	0x0081
#define _PQ38_VERSION	0x8021


/* e500 definitions */
#define   SPR_DBCR0			308
#define   SPR_DBSR			304
#define   SPR_DEAR			61
#define   SPR_ESR			62
#define   SPR_L1CSR0     	0x3f2   		/* L1 Data Cache Control and Status Register 0 */
#define   L1CSR0_CPE        0x00010000		/* Data Cache Parity Enable */
#define   L1CSR0_DCFI       0x00000002      /* Data Cache Flash Invalidate */
#define   L1CSR0_DCE        0x00000001      /* Data Cache Enable */
#define   SPR_L1CSR1   	    0x3f3   		/* L1 Instruction Cache Control and Status Register 1 */
#define   L1CSR1_CPE        0x00010000		/* Instruction Cache Parity Enable */
#define   L1CSR1_ICFI       0x00000002      /* Instruction Cache Flash Invalidate */
#define   L1CSR1_ICE        0x00000001      /* Instruction Cache Enable */

#define SPR_MMUCSR0	   0x3f4   /* MMU control and status register 0 */
#define SPR_MAS0       0x270   /* MMU Assist Register 0 */
#define SPR_MAS1       0x271   /* MMU Assist Register 1 */
#define SPR_MAS2       0x272   /* MMU Assist Register 2 */
#define SPR_MAS3       0x273   /* MMU Assist Register 3 */
#define SPR_MAS4       0x274   /* MMU Assist Register 4 */
#define SPR_MAS5       0x275   /* MMU Assist Register 5 */
#define SPR_MAS6       0x276   /* MMU Assist Register 6 */
#define SPR_MAS7	   0x3B0   /* MMU Assist Register 7 */

#define SPR_IVOR32     0x210   /* Interrupt Vector Offset Register 32 */
#define SPR_IVOR33     0x211   /* Interrupt Vector Offset Register 33 */
#define SPR_IVOR34     0x212   /* Interrupt Vector Offset Register 34 */
#define SPR_IVOR35     0x213   /* Interrupt Vector Offset Register 35 */
#define SPR_SPEFSCR    0x200   /* SPE & Embedded FP Status & Control */

#define SPR_MCSRR0     0x23a   /* Machine Check Save and Restore Register 0 */
#define SPR_MCSRR1     0x23b   /* Machine Check Save and Restore Register 1 */
#define SPR_BUCSR	   0x3f5   /* Branch Control and Status Register */
#define SPR_BBEAR      0x201   /* Branch Buffer Entry Address Register */
#define SPR_BBTAR      0x202   /* Branch Buffer Target Address Register */
#define SPR_PID1       0x279   /* Process ID Register 1 */
#define SPR_PID2       0x27a   /* Process ID Register 2 */
#define SPR_MCSR	   0x23c   /* Machine Check Syndrome register */
#define SPR_MCAR	   0x23d   /* Machine Check Address register */



/*
 * Convenient assembly values.
 */

#define COND_EQ		2
#define MSR_DE		0x00000200	/* DE bit of MSR (bit 22) - only for e500 */
#define MSR_SE		0x00000400	/* SE bit of MSR (bit 21) */
#define MSR_CE		0x00020000	/* CE bit of MSR (bit 14) */
#define MSR_EE		0x00008000	/* EE bit of MSR (bit 16) */
#define MSR_ME		0x00001000	/* ME bit of MSR (bit 19) */
#define MSR_RI		0x00000002	/* RI bit of MSR (bit 30) */
#define MSR_DR		0x00000010	/* DR bit of MSR (bit 27) */
#define MSR_IR		0x00000020	/* IR bit of MSR (bit 26) */
#define MSR_FP		0x00002000	/* FP bit of MSR (bit 18) */
#define MSR_VEC		0x02000000  	/* VEC bit of MSR (bit 6) */ /* AltiVec support */

#endif

#define   SPR_DBCR0	308
#define   SPR_DBSR	304

#define DBCR0_IDM       0x40000000
#define DBCR0_ICMP      0x08000000
#define DBCR0_IRPT      0x02000000
#define DBCR0_CIRPT     0x00000040
#define DBCR0_TRAP      0x01000000
#define DBSR_ICMP       0x08000000 /* Instruction Complete Debug Event */

#define E500MC_MFMSR   	0x7C0000A6
#define E500MC_MTMSR   	0x7C000124
#define E500MC_WRTEE   	0x7C000106
#define E500MC_WRTEEI   0x7C000146 /*wrteei 0 */
#define E500MC_RFI     	0x4C000064
#define E500MC_RFCI    	0x4C000066
#define E500MC_RFDI    	0x4C00004E
#define E500MC_RFMCI   	0x4C00004C
#define E500MC_RFGI    	0x4C0000CC
#define E500MC_MSR_INSTR  0xFC0007FE


#define MAS0_TLB1_SEL	0x10000000
#define MAS0_TLB0_ESEL	0x00030000
#define MAS0_TLB1_ESEL	0x003F0000
#ifndef MAS1_VALID
#define MAS1_VALID		0x80000000
#endif
#define MAS2_TLB0_WAYSEL  0x0007F000

#endif	// #ifndef __eppcreg_h__
