/******************************************************************************************/
/*

DESCRIPTION

	Command dispatcher
	
COPYRIGHT

	Copyright 1999-2003, 2006, 2007, 2009, 2010 Freescale Semiconductor, Inc.
	
*/
/******************************************************************************************/

#include "trk_prefix.h"

#include "usr_put.h"		/* must be included before msgcmd.h */
#include "nubassrt.h"
#include "msghndlr.h"
#include "dispatch.h"
#include "msg.h"
#include "mem_TRK.h"
#include "msgparse.h"
#include "support.h"
#include "break.h"
#ifdef IS_SMP
#include "smp.h"
#endif


#ifdef VIRTUAL_DISPATCH
/****************************************************************************/
/*
 *	The dispatch table is a jumptable for the handlers for each command.
 *	This table contains the default, minimum set.  The table can be
 *	overridden at runtime for customization by a custom nub.
 */
/****************************************************************************/

#if __MWERKS__
#pragma options align=power
#endif /* __MWERKS__ */

unsigned int gDispatchTableSize = 0;

DispatchEntry gDispatchTable[] = {
	{	&DoPing				},				/* 0x00 Ping */
	{	&DoConnect			},				/* 0x01 Connect */
	{	&DoDisconnect		},				/* 0x02 Disconnect */
	{	&DoReset			},				/* 0x03 Reset */
	{	&DoVersions			},				/* 0x04 Versions */
	{	&DoSupportMask		},				/* 0x05 SupportMask */
	{	&DoCPUType			},				/* 0x06 CPUType */
	{	&DoConfigTransport	},				/* 0x07 Configure Transport */
	{	&DoConfigAutoDownload	},				/* 0x08 Configure Auto Download */
	
	{	&DoUnsupported		},				/* 0x09 reserved */
	{	&DoUnsupported		},				/* 0x0A reserved */
	{	&DoUnsupported		},				/* 0x0B reserved */
	{	&DoUnsupported		},				/* 0x0C reserved */
	{	&DoUnsupported		},				/* 0x0D reserved */
	{	&DoUnsupported		},				/* 0x0E reserved */
	{	&DoUnsupported		},				/* 0x0F reserved */
	
	{	&DoReadMemory		},				/* 0x10 ReadMemory */
	{	&DoWriteMemory		},				/* 0x11 WriteMemory */
	{	&DoReadRegisters	},				/* 0x12 ReadRegisters */
	{	&DoWriteRegisters	},				/* 0x13 WriteRegisters */
	{	&DoUnsupported		},				/* 0x14 expansion: state command */
	{	&DoUnsupported		},				/* 0x15 expansion: state command */
	{	&DoFlushCache		},				/* 0x16 FlushCache */
	{	&DoCheckTargetState		},				/* 0x17 CheckTargetState */

	{	&DoContinue			},				/* 0x18 Continue */
	{	&DoStep				},				/* 0x19 Step */
	{	&DoStop				},				/* 0x1A Stop */ 
#if TRK_SUPPORT_BREAKPOINTS
	{	&DoSetBreak			},				/* 0x1B Set Breakpoint */
	{	&DoClearBreak		},				/* 0x1C Clear Breakpoint */
#else
	{	&DoUnsupported		},				/* 0x1B Set Breakpoint (not supported) */
	{	&DoUnsupported		},				/* 0x1C Clear Breakpoint (not supported) */
#endif
	{	&DoUnsupported		},				/* 0x1D expansion: control command */
#if DS_PROTOCOL == DS_PROTOCOL_RTOS && TRK_SUPPORT_BREAKPOINTS
	{	&DoModifyBreakThread},				/* 0x1E Modify Breakpoint Thread */
#else
	{	&DoUnsupported		},				/* 0x1E not supported at this level */
#endif
	{	&DoUnsupported		},				/* 0x1F expansion: control command */
	
	{	&DoNotifyFileInput	},				/* 0x20 Notify File Input */
	{	&DoBlockFileIo		},				/* 0x21 Block File IO */

#if DS_PROTOCOL == DS_PROTOCOL_RTOS
	{	&DoUnsupported		},				/* 0x22 reserved */
	{	&DoUnsupported		},				/* 0x23 reserved */
	{	&DoUnsupported		},				/* 0x24 reserved */
	{	&DoUnsupported		},				/* 0x25 reserved */
	{	&DoUnsupported		},				/* 0x26 reserved */
	{	&DoUnsupported		},				/* 0x27 reserved */
	
	{	&DoUnsupported		},				/* 0x28 reserved */
	{	&DoUnsupported		},				/* 0x29 reserved */
	{	&DoUnsupported		},				/* 0x2A reserved */
	{	&DoUnsupported		},				/* 0x2B reserved */
	{	&DoUnsupported		},				/* 0x2C reserved */
	{	&DoUnsupported		},				/* 0x2D reserved */
	{	&DoUnsupported		},				/* 0x2E reserved */
	{	&DoUnsupported		},				/* 0x2F reserved */
	
	{	&DoUnsupported		},				/* 0x30 reserved */
	{	&DoUnsupported		},				/* 0x31 reserved */
	{	&DoUnsupported		},				/* 0x32 reserved */
	{	&DoUnsupported		},				/* 0x33 reserved */
	{	&DoUnsupported		},				/* 0x34 reserved */
	{	&DoUnsupported		},				/* 0x35 reserved */
	{	&DoUnsupported		},				/* 0x36 reserved */
	{	&DoUnsupported		},				/* 0x37 reserved */
	
	{	&DoUnsupported		},				/* 0x38 reserved */
	{	&DoUnsupported		},				/* 0x39 reserved */
	{	&DoUnsupported		},				/* 0x3A reserved */
	{	&DoUnsupported		},				/* 0x3B reserved */
	{	&DoUnsupported		},				/* 0x3C reserved */
	{	&DoUnsupported		},				/* 0x3D reserved */
	{	&DoUnsupported		},				/* 0x3E reserved */
	{	&DoUnsupported		},				/* 0x3F reserved */
	
	/*
	** The following commands may or may not be supported by a
	** particular OS implementation.  If they are supported, use
	** OverrideDispatch() to set the appropriate handler functions.
	*/
	
	{	&DoUnsupported		},				/* 0x40 OSCreateItem */
	{	&DoUnsupported		},				/* 0x41 OSDeleteItem */
	{	&DoUnsupported		},				/* 0x42 OSReadInfo */
	{	&DoUnsupported		},				/* 0x43 OSWriteInfo */
	{	&DoUnsupported		},				/* 0x44 reserved */
	{	&DoUnsupported		},				/* 0x45 reserved */
	{	&DoUnsupported		},				/* 0x46 reserved */
	{	&DoUnsupported		},				/* 0x47 reserved */
	
	{	&DoOsWriteFile		},				/* 0x48 OSWriteFile */
	{	&DoOsReadFile		},				/* 0x49 OSReadFile */
	{	&DoOsOpenFile		},				/* 0x4A OSOpenFile */
	{	&DoOsCloseFile		},				/* 0x4B OSCloseFile */
	{	&DoOsPositionFile	},				/* 0x4C OSPositionFile */
	{	&DoUnsupported		},				/* 0x4D reserved */
	{	&DoUnsupported		},				/* 0x4E reserved */
	{	&DoUnsupported		},				/* 0x4F reserved */

#endif /* #if DS_PROTOCOL == DS_PROTOCOL_RTOS */
	
	{	(DispatchFunctionPtr) 0 }			/* sentinel */
};
#endif /*VIRTUAL_DISPATCH*/

/*
** Keep track of the next sequence ID expected from the host.
*/
#ifndef IS_SMP
ui8 gNextRcvSeqId = 1;
#else
#define gNextRcvSeqId PRIVATE_DATA(RECEIVED_SEQUENCE)
#endif


/****************************************************************************/
/*
 *	InitializeDispatcher
 */
/****************************************************************************/
DSError InitializeDispatcher()
{
#ifdef VIRTUAL_DISPATCH
	gDispatchTableSize = (sizeof(gDispatchTable) / sizeof(DispatchEntry)) - 1;
#endif

	gNextRcvSeqId = 1;

	return kNoError;
}

#ifdef VIRTUAL_DISPATCH
/****************************************************************************/
/*
 *	OverrideDispatch
 */
/****************************************************************************/
DSError OverrideDispatch(MessageCommandID cmdID, const DispatchEntry* newEntry,
								 DispatchEntry* returnedOldEntry)
{
	DSError result = kNoError;				/* assume OK */
	
	ASSERT(gDispatchTableSize);
		
	if (cmdID >= gDispatchTableSize) {

		result = kDispatchErr;

	} else {

		if (returnedOldEntry) {
			/* store the return value if the caller asked to get the old one */
			
			TRK_memcpy(returnedOldEntry, gDispatchTable + cmdID,
					sizeof(*returnedOldEntry));
		}
		
		/* stuff in the new dispatch vector */
		TRK_memcpy(gDispatchTable + cmdID, newEntry, sizeof(*newEntry));
	}
	
	return result;
}
#endif /* VIRTUAL_DISPATCH */


/****************************************************************************/
/*
 *	DispatchMessage
 */
/****************************************************************************/
DSError DispatchMessage(MessageBuffer* b)
{
	DSError err = kDispatchErr;		/* assume an error */
	MessageCommandID command;
#if TRK_MSG_SEQUENCE_IDS
	ui8 seqId;
#endif

#ifdef VIRTUAL_DISPATCH
	ASSERT(gDispatchTableSize);
#endif
	ASSERT(b);

	err = TrkParseMessageSegment( b, &gTrkMsgHeader, true );
	command = (MessageCommandID)b->fFields.fData[ TRK_MSG_COMMAND_INDEX ];
	
#if TRK_MSG_SEQUENCE_IDS
	seqId = b->fFields.fData[ TRK_MSG_SID_INDEX ];

	/*
	** A sequence ID of 0 is a special case - it is always accepted
	** and it resets the sequence such that the next sequence ID
	** for both the host and the target will be 1.
	*/
	if (seqId == 0)
	{
		ResetSendSeqId( 1 );
		gNextRcvSeqId = 0; /* will be incremented below */
	}

	/*
	** Normal case - the received sequence ID matches the expected value.
	** Process the message and update the expected value.
	*/
	if (seqId == gNextRcvSeqId)
#endif /* #if TRK_MSG_SEQUENCE_IDS */
	{
#ifdef VIRTUAL_DISPATCH
		if (command < gDispatchTableSize) {
			DispatchFunctionPtr fp = gDispatchTable[command].fn;
					 
			err = (*fp)(b);			/* call the command handler */
		}
		
#else

		switch(command) {
			case kDSConnect:			err = DoConnect(b);			break;
			case kDSDisconnect	:		err = DoDisconnect(b);		break;
			case kDSReset:				err = DoReset(b);			break;
			case kDSVersions:			err = DoVersions(b);		break;
			case kDSSupportMask:		err = DoSupportMask(b);		break;
	
			case kDSReadMemory:			err = DoReadMemory(b);		break;
			case kDSWriteMemory:		err = DoWriteMemory(b);		break;
			case kDSReadRegisters:		err = DoReadRegisters(b);	break;
			case kDSWriteRegisters:		err = DoWriteRegisters(b);	break;
	
			case kDSContinue:			err = DoContinue(b);		break;
			case kDSStep:				err = DoStep(b);			break;
			default:
				__puts("invalid command: ");
				__puthex2(command);
				__puts( "\r\n" );
				break;
		}
	
#endif
		/*
		** Increment the next expected value.  Once it gets to 0xff, go
		** back to 0.
		*/

		gNextRcvSeqId = (gNextRcvSeqId == 0xff) ? 1 : (gNextRcvSeqId + 1);
	}

#if TRK_MSG_SEQUENCE_IDS
	else if (gPreviousAck != NULL &&
			 gPreviousAck->fFields.fData[ TRK_MSG_SID_INDEX ] == seqId)
	{
		/*
		** A duplicate of the previous message was received.  Re-send
		** the saved reply.
		*/
		
		err = SendACK( gPreviousAck );
	}
	else
	{
		/*
		** An out-of-sequence message was received.  Send back a NAK
		** with the appropriate error code and the expected sequence ID.
		*/

		b->fFields.fData[ TRK_MSG_SID_INDEX ] = gNextRcvSeqId;
		err = StandardACK( b, kDSReplyNAK, kDSReplySequenceMissing );
	}
#endif /* TRK_MSG_SEQUENCE_IDS */
	
	return err;
}

