/******************************************************************************************/
/*

DESCRIPTION
	
	Standalone Standard C Library Implementation for memory operations.
	This is a target-specific implementation for PowerPC.  It will
	probably work for other target processors as well, but this one
	has been improved specifically for PowerPC.
	
	Derived from MSL C (CodeWarrior 10).
	
COPYRIGHT

	Copyright 2000, 2002, 2003, 2006, 2007, 2009 Freescale Semiconductor, Inc.
	
*/
/******************************************************************************************/

#include "trk_prefix.h"

#include "reset.h" /* forces funcs into reset section, if desired */
#include "mem_TRK.h"

#ifdef __POWERPC__
#pragma push
#pragma section code_type ".init" data_mode=far_abs code_mode=far_abs
static void TRK_fill_mem(void * dst, int val, unsigned long n);
#pragma pop
#else
static void TRK_fill_mem(void * dst, int val, unsigned long n);
#endif

void * TRK_memcpy(void * dst, const void * src, size_t n)
{
	const	char * p;
				char * q;
	
	for (p = (const char *) src - 1, q = (char *) dst - 1, n++; --n;)
		*++q = *++p;

	return(dst);
}


void * (TRK_memmove)(void * dst, const void * src, size_t n)
{
	const	char * p;
				char * q;
				int		 rev = ((unsigned long) src < (unsigned long) dst);
	
	if (!rev)
	{
		
		for (p = (const char *) src - 1, q = (char *) dst - 1, n++; --n;)
			*++q = *++p;
	
	}
	else
	{
		for (p = (const char *) src + n, q = (char *) dst + n, n++; --n;)
			*--q = *--p;
	}
	return(dst);
}


/*
	mem_funcs.c
*/

/*
#define cps	((unsigned char *) src)
#define cpd	((unsigned char *) dst)
#define lps	((unsigned long *) src)
#define lpd	((unsigned long *) dst)
*/
#define deref_auto_inc(p)	*++(p)

static void TRK_fill_mem(void * dst, int val, unsigned long n)
{
	unsigned long			v = (unsigned char) val;
	unsigned long			i;
	union {
		unsigned char *cpd;
		unsigned long *lpd;
	} dstu;
	
	dstu.cpd = ((unsigned char *) dst) - 1;
	
	if (n >= 32)
	{
		i = (~ (unsigned long) dstu.cpd) & 3;
		
		if (i)
		{
			n -= i;
			
			do
				deref_auto_inc(dstu.cpd) = v;
			while (--i);
		}
	
		if (v)
			v |= v << 24 | v << 16 | v <<  8;
		
		dstu.lpd = ((unsigned long *) (dstu.cpd + 1)) - 1;
		
		i = n >> 5;
		
		if (i)
			do
			{
				deref_auto_inc(dstu.lpd) = v;
				deref_auto_inc(dstu.lpd) = v;
				deref_auto_inc(dstu.lpd) = v;
				deref_auto_inc(dstu.lpd) = v;
				deref_auto_inc(dstu.lpd) = v;
				deref_auto_inc(dstu.lpd) = v;
				deref_auto_inc(dstu.lpd) = v;
				deref_auto_inc(dstu.lpd) = v;
			}
			while (--i);
		
		i = (n & 31) >> 2;
		
		if (i)
			do
				deref_auto_inc(dstu.lpd) = v;
			while (--i);
		
		dstu.cpd = ((unsigned char *) (dstu.lpd + 1)) - 1;
		
		n &= 3;
	}
	
	if (n)
		do
			deref_auto_inc(dstu.cpd) = v;
		while (--n);
	
	return;
}

void * TRK_memset(void * dst, int val, size_t n)
{
	TRK_fill_mem(dst, val, n);
	
	return(dst);
}

