/******************************************************************************************/
/*

DESCRIPTION

	Contains stubs for target-specific extensions to the
	monitor command constants and structures defined in 
	msgcmd.h.  To extend the CodeWarriorTRK API for a specific
	target, copy this file and make target-specific
	modifications to the copy.  Then include the modified
	copy from any source files which make use of the extensions.
	
COPYRIGHT

	Copyright 1999-2002, 2006, 2007, 2009 Freescale Semiconductor, Inc.
	
*/
/******************************************************************************************/

#ifndef __MSGTARG_H__
#define __MSGTARG_H__

#include "msgcmd.h"

/****************************************************************************/
/*
** Define extended, target-specific MessageCommandID values here.
**
** Extended command values should not conflict with the pre-defined
** values.  See msgcmd.h for the list of pre-defined values.
*/
/****************************************************************************/

typedef enum
{
	/*
	** 0x70 - 0x7F available for host->target target-specific commands
	** 0xE0 - 0xEF available for target->host target-specific commands
	*/
} TargMessageCommandID;

/****************************************************************************/
/*
** Define extended, target-specific DSMessageStepOptions values here.
**
** The pre-defined values are:
**
**   kDSStepIntoCount = 0x00	Exec count instructions & stop
**   kDSStepIntoRange = 0x01	Exec until PC is out of specifed range
**   kDSStepOverCount = 0x10	Step over 1*count instructions & stop
**   kDSStepOverRange = 0x11	Step over until PC is out of specified range
**
** Extended option values should not conflict with the pre-defined
** values.
*/
/****************************************************************************/

typedef enum {
} DSTargMessageStepOptions;


/****************************************************************************/
/*
** Define extended, target-specific DSMessageStopOptions values here.
**
** The pre-defined values are:
**
**   kDSStopSytem	= 0x0		Stop the entire system
**   kDSStopProcess	= 0x1		Stop all threads in a specific process
**   kDSStopThread	= 0x2		Stop a specific thread in a specific process
**
** Extended option values should not conflict with the pre-defined
** values.
*/
/****************************************************************************/

typedef enum {
} DSTargMessageStopOptions;

/****************************************************************************/
/*
** Define extended, target-specific DSMessageBreakOptions values here.
**
** The pre-defined values are:
**
**   kDSBreakSoftware	= 0x00		Set/clear a software breakpoint
**   kDSBreakHardware	= 0x01		Set/clear a hardware breakpoint
**
** Extended option values should not conflict with the pre-defined
** values.
*/
/****************************************************************************/

typedef enum {
} DSTargMessageBreakOptions;

/****************************************************************************/
/*
** Define extended, target-specific DSMessageDownloadOptions values here.
**
** The pre-defined values are:
**
**   kDSMessageDownloadTFTP		= 0x0
**
** Extended option values should not conflict with the pre-defined
** values.
*/
/****************************************************************************/

typedef enum {
} DSTargMessageDownloadOptions;

/****************************************************************************/
/*
** Define extended, target-specific DSOSItemTypes values here.
**
** The pre-defined values are:
**
**   kDSOSProcessItem	= 0x0000
**   kDSOSThreadItem	= 0x0001
**   kDSOSDLLItem		= 0x0002
**   kDSOSAppItem		= 0x0003
**   kDSOSMemBlockItem	= 0x0004
**   kDSOSProcAttachItem= 0x0005
**   kDSOSThreadAttachItem= 0x0006
**   0x0007 - 0x00ff reserved for expansion
**
** Extended item type values should not conflict with the pre-defined
** or reserved values.
*/
/****************************************************************************/

typedef enum {
} DSTargOSItemTypes;

/****************************************************************************/
/*
** Define extended, target-specific DSOSInfoTypes values here.
**
** The pre-defined values are:
**
**   kDSOSProcessList	= 0x0000
**   kDSOSProcessState	= 0x0001
**   kDSOSThreadList	= 0x0002
**   kDSOSThreadState	= 0x0003
**   kDSOSDLLList		= 0x0004
**   kDSOSDLLState		= 0x0005
**   0x0006 - 0x00ff reserved for expansion
**
** Extended info type values should not conflict with the pre-defined
** or reserved values.
*/
/****************************************************************************/

typedef enum {
} DSTargOSInfoTypes;


#endif /* __MSGTARG_H__ */


/****************************************************************************/
/****************************************************************************/
/*                 A D D I T I O N A L   C O M M A N D S					*/
/****************************************************************************/
/****************************************************************************/

