/******************************************************************************************/
/*

DESCRIPTION

	Standalone assertions for the Target-resident Kernel (TRK) for
	embedded products.
	
	Requires "exit" to be implemented.
	
COPYRIGHT

	Copyright 1999-2002, 2006, 2007, 2009 Freescale Semiconductor, Inc.
	
*/
/******************************************************************************************/

#include "trk_prefix.h"

/*
 *	System includes
 */
#ifndef _NO_SYSTEM_INCLUDES
#include <stdlib.h>
#endif

/*
 *	Debugger Nub includes
 */
#include "dstypes.h"
#include "nubassrt.h"
#include "usr_put.h"

/****************************************************************************/

/*
** If you wish to allow TRK to die (call exit()), define this
** to 1 in target-specific headers.
*/
#ifndef ALLOW_DIE
	#define ALLOW_DIE		0
#endif


void NubAssertionFailed(char * condition, char * filename, int lineno, bool die)
{
#if __MWERKS__
	#pragma unused(condition, filename)
#endif /* __MWERKS__ */
	
	char linestr[6];
	int order;
	
	for (order = 4; order >= 0; order--) {
		linestr[order] = '0' + (lineno % 10);
		lineno /= 10;
	}
	linestr[5] = 0;
	
	__puts("Assert failed: file = ");
	__puts(filename);
	__puts("; line = ");
	__puts(linestr);
	__puts("; ");
	__puts(condition);
	__puts("\r\n");

#if ALLOW_DIE
	if (die) {
		exit(-1);
	}
#endif /* #if ALLOW_DIE */
}
