/******************************************************************************************/
/*

DESCRIPTION

	TRK initialization functions.

COPYRIGHT

	Copyright 1999-2004, 2006, 2007, 2009 Freescale Semiconductor, Inc.
	
*/
/******************************************************************************************/

#include "trk_prefix.h"

#include "usr_put.h"		// must be included before msgcmd.h
#include "dstypes.h"
#include "nubinit.h"
#include "nubevent.h"
#include "dispatch.h"
#include "target.h"
#include "support.h"
#include "targimpl.h"
#include "string_TRK.h"
#include "mem_TRK.h"
#include "transport.h"
#include "transport_tbl.h"
#include "break.h"

#ifndef IS_SMP
extern volatile unsigned char gInputPending;
#else
#define gInputPending PRIVATE_DATA(INPUT_PENDING)
#endif

/*
** Global endian flag that is initialized on startup.
** This should be the same value even for a SMP trk agent
*/

bool gBigEndian;

/******************************************************************************/
/*
	InitializeNub
*/
/******************************************************************************/

DSError InitializeNub(void)
{
	DSError			err;

	err = InitializeEndian();

	/*
	** Initialize output buffer for diagnostic output.
	*/

	if (err == kNoError)
		usr_put_initialize();

	if (err == kNoError)
		err = InitializeEventQueue();
	
	if (err == kNoError)
		err = InitializeMessageBuffers();

	if (err == kNoError)
		err = InitializeDispatcher();
		
#if TRK_SUPPORT_BREAKPOINTS
	if (err == kNoError)
		err = InitializeBreakpoints();
#endif /* #if TRK_SUPPORT_BREAKPOINTS */

	/*
		don't try to print anything before initializing the output port
	*/
	if (err == kNoError)
	{
#if TRK_TRANSPORT_INT_DRIVEN
		gInputPending = false;
		TargetSetInputPendingPtr( &gInputPending );
#endif /* TRK_TRANSPORT_INT_DRIVEN */

		err = InitializeTransport();
	}

	
	__puts( "Calling InitializeTarget\r\n" );
	if (err == kNoError)
		err = InitializeTarget();
	
	__puts( "Returning " );
	__puthex8( err );
	__puts( " from InitializeNub\r\n" );

	return err;
}

/******************************************************************************/
/*
	TerminateNub
*/
/******************************************************************************/

DSError TerminateNub(void)
{
	DSError err = kNoError;
	int index;
	
	/*
	** Terminate all comm ports.
	*/
	
	for (index = 0;
		index < gTrkTransportNumCommPorts && err == kNoError;
		index++)
		err = TransportTerminateIndex( index );


	TerminateEventQueue();

	TerminateMessageBuffers();

	__puts("Exiting CodeWarriorTRK.\r\n");
	return kNoError;
}

/******************************************************************************/
/*
	NubWelcome
*/
/******************************************************************************/

#ifdef BOARD_WELCOME_STRING
void board_display( char * );
#endif

void NubWelcome( void )
{
#ifndef SUPPRESS_WELCOME_MESSAGE
	size_t count;
	DSIOResult io_result;
#ifndef USE_SMALL_STACK
	char str[ DS_MAXREADWRITELENGTH ];
#else
	char *str;
	str = TRK_malloc(DS_MAXREADWRITELENGTH);
#endif
#endif /* #ifndef SUPPRESS_WELCOME_MESSAGE */

	/*
	** If a board welcome string is defined, display it here.
	*/
	
#ifdef BOARD_WELCOME_STRING
	board_display( BOARD_WELCOME_STRING );
#endif

#ifndef SUPPRESS_WELCOME_MESSAGE
	/*
	** Build welcome string in buffer.
	*/

	str[0] = '\0';
	
	TRK_strcat( str, "\r\nCodeWarrior Target Resident Kernel for " );
	TRK_strcat( str, DS_TARGET_NAME );
	TRK_strcat( str, "\r\nVersion " );
	TRK_strcat( str, DS_KERNEL_VERSION_STRING );
	TRK_strcat( str, " implementing CodeWarriorTRK API version " );
	TRK_strcat( str, DS_PROTOCOL_VERSION_STRING );
	TRK_strcat( str, "\r\n" );

	/*
	** Send as a WriteFile command to stdout.
	*/
	
	count = TRK_strlen( str );
	SuppAccessFile( kDSStdout, (ui8 *)str, &count, &io_result, false, false
#if DS_PROTOCOL == DS_PROTOCOL_RTOS
					, TRK_PROCESS_ID, TRK_THREAD_ID
#endif
	 );

#ifdef USE_SMALL_STACK
	TRK_free(str);
#endif

#endif /* #ifndef SUPPRESS_WELCOME_MESSAGE */
}

/******************************************************************************/
/*
	InitializeEndian
	
	Tests the endian-ness of the processor and sets the global
	gBigEndian accordingly.
*/
/******************************************************************************/
DSError InitializeEndian( void )
{
	DSError	err = kNoError;
	ui32	test;
	ui8		*byte_alias = (ui8 *)&test;
	
	gBigEndian = true;

	/*
	** Write a specific 4-byte sequence and then read it as
	** a 32-bit word.  Big-endian systems yield one value and
	** little-endian systems yield another.
	*/
	
	byte_alias[ 0 ] = 0x12;
	byte_alias[ 1 ] = 0x34;
	byte_alias[ 2 ] = 0x56;
	byte_alias[ 3 ] = 0x78;
	
	if (test == 0x12345678)
		gBigEndian = true;
	else if (test == 0x78563412)
		gBigEndian = false;
	else
		err = kInternalError;
		
	return( err );
}

