/******************************************************************************************/
/*

DESCRIPTION

	Default timeout routines for CodeWarriorTRK.  This should not be
	included by any of the portable files.  It is intended to
	be included by target.h so that any given target can define
	a different timeout mechanism simply by defining ResetTimeout
	and Timeout differently in target.h.

COPYRIGHT

	Copyright 1999, 2002, 2006, 2007, 2009 Freescale Semiconductor, Inc.
	
*/
/******************************************************************************************/

#ifndef TRK_TIMEOUT_H
#define TRK_TIMEOUT_H

/*
** A timeout implementation must define TimeoutType and provide
** functions or macros that conform to the following prototypes:
**
**	void ResetTimeout( TimeoutType *timer_ptr );
**		// Clear the given timer object and start timing.
**
**	bool Timeout( TimeoutType *timer_ptr );
**		// Test the given timer object.  If timeout has occurred,
**		// return true, else return false.
**
*/

/*********************************************************************
**  The following is a default implementation for the timeout 
**	routines.   It can be used on any target.  Individual targets
**	may use different implementations.
*********************************************************************/

/*
** The TIMEOUT_COUNT should be defined as the # of checks that
** can be performed before a timeout occurs.  The amount of
** time that passes for a given timeout count depends on
** the CPU speed and the number of cycles that execute between
** each check for timeout.  Therefore, it is actually dependent
** on the implementation of the routine which uses these timeout
** functions.  The TIMEOUT_COUNT will be defined with an assumption
** that relatively few cycles will pass between checks.
**
** An example of a definition of TIMEOUT_COUNT with a desired
** timeout of 5 seconds on a 100MHz system:
**
**	#define CPU_SPEED				(100 * 1000000)
**	#define TIMEOUT_SECS			5
**	#define CHECK_CYCLES			20
**
**	#define TIMEOUT_COUNT			(TIMEOUT_SECS * (CPU_SPEED / CHECK_CYCLES))
**
*/


#ifndef TIMEOUT_COUNT
	#error "TIMEOUT_COUNT must be defined to use the default timeout macros."
#endif


typedef unsigned int 	TimeoutType;

#define	ResetTimeout( timer_ptr )			(*timer_ptr = 0);
#define Timeout( timer_ptr )				((++(*timer_ptr)) >= \
												TIMEOUT_COUNT)
#endif /* ndef TRK_TIMEOUT_H */
