/******************************************************************************************/
/*

DESCRIPTION

	Portable API for debugging CWDS.
	
	Development support functions for debugging output.  These functions
	can be used to write to a buffer in memory and later examined using
	a memory dump view, or by using a UART.

COPYRIGHT

	Copyright 1999-2002, 2004, 2006, 2007, 2009 Freescale Semiconductor, Inc.
	
*/
/******************************************************************************************/

#ifndef __USR_PUT_H__
#define __USR_PUT_H__

#include "usr_put_config.h"

__extern_c

	int usr_putchar(int c);
	int usr_puts(const char *s);
	void usr_put_initialize( void );

	/*
	** Dump memory buffer to conole.
	*/

	void __do_console_dump( void );

#if defined(DEBUGIO_RAM) && defined(DB_RAM_CONSOLE_DUMP)
	#define __console_dump()	__do_console_dump()
#else
	#define __console_dump()
#endif

	/*
		Output functions, helpful for debugging
	*/

	int __do_putchar(char c);
	int __do_puts(const char *s);
	int __do_puthex32(void *x);
	int __do_puthex20(void *x);

#if __MWERKS__
  #if __option( longlong )
	int __do_puthex16(unsigned long long x);
  #endif /* if/else __option( longlong ) */
#else /* NOT __MWERKS__ */
  #if __GNUC__
	int __do_puthex16(unsigned long long x);
  #endif /* if/else __GNUC__ */
#endif /* if/else __MWERKS__ */

	int __do_puthex8(unsigned long);
	int __do_puthex4(unsigned short);
	int __do_puthex2(unsigned char);

#if defined( DEBUGIO_RAM ) || defined( DEBUGIO_SERIAL ) || defined( DEBUGIO_CUSTOM )
	#define __putchar( c )		__do_putchar( c )
	#define __puts( s )			__do_puts( s )
	#define __puthex32( v )		__do_puthex32( ((void*)v) )
	#define __puthex20( v )		__do_puthex20( v )
	#define __puthex16( v )		__do_puthex16( v )
	#define __puthex8( v )		__do_puthex8( v )
	#define __puthex4( v )		__do_puthex4( v )
	#define __puthex2( v )		__do_puthex2( v )
	
	#define DEBUG_ASSERT		1
	#ifdef DEBUG_MSGCMD
	#undef DEBUG_MSGCMD
	#endif
	#define DEBUG_MSGCMD		1
#else
	// The ((void)0) hushes up warnings about an empty body in an else statement
	#define __putchar( c )	((void)0)
	#define __puts( s ) 	((void)0)
	#define __puthex32( v )	((void)0)
	#define __puthex20( v )	((void)0)
	#define __puthex16( v )	((void)0)
	#define __puthex8( v )	((void)0)
	#define __puthex4( v )	((void)0)
	#define __puthex2( v )	((void)0)

	#define DEBUG_ASSERT		0
	#define DEBUG_MSGCMD		0
#endif

	/*
		Serial-specific functions
	*/
	int usr_puts_serial(const char *s);
	int usr_putchar_serial(int c);

__end_extern_c

#endif /* __USR_PUT_H__ */
